@@ -27,14 +27,16 @@ module Solve
     def to_s
       "#{name} (#{constraint})"
     end
+    alias :inspect :to_s
 
     # @param [Object] other
     #
     # @return [Boolean]
     def ==(other)
       other.is_a?(self.class) &&
-      self.artifact == other.artifact &&
-      self.constraint == other.constraint
+        name == other.name &&
+        artifact == other.artifact &&
+        constraint == other.constraint
     end
     alias_method :eql?, :==
   end
